const fn expand_invert_mod2k_step(
a: &Odd<UintRef>,
buf: &mut UintRef,
buf_init_len: usize,
scratch: (&mut UintRef, &mut UintRef),
)Expand description
One step of the Hensel quadratic modular inverse calculation, doubling the width
of the inverted output, and wrapping at capacity of buf.